@@ -50,11 +50,7 @@ class Base(ABC):
             raise ValueError()
 
         d, a, b, rho = resample(
-            self._thickness,
-            self._velocity_p,
-            self._velocity_s,
-            self._density,
-            dz,
+            self._thickness, self._velocity_p, self._velocity_s, self._density, dz,
         )
         self._thickness = d
         self._velocity_p = a
